@@ -1,4 +1,4 @@
-# last modified 2017-04-05 by J. Fox
+# last modified 2018-07-28 by J. Fox
 
 globalVariables(c('top', 'statisticFrame', 'statisticVariable', 'buttonsFrame',
                   '.activeModel', 'varVariable', 'rhsVariable', 'varFrame', 'formulaFrame',
@@ -56,4 +56,5 @@ globalVariables(c('top', 'statisticFrame', 'statisticVariable', 'buttonsFrame',
                   'legendVariable', 'legendFrame', 'legendPositionVariable', 'legendPositionFrame',
                   'valuesOrQuantilesVariable', 'valuesOrQuantilesFrame',
                   'conditionalVariable', 'colorsVariable', 'colorsFrame', 'conditionalFrame',
-                  'countsVariable'))
+                  'countsVariable', 'allPredictorEffectsFrame', 'allPredictorEffectsVariable', 'familyFrame', 'familyVariable',
+                  'bonfVariable', 'cookVariable', 'hatVariable', 'studentVariable', 'varsFrame'))
